declare enum MutantStatus {
    /**
     * The status of a survived mutant, because it was not covered by any test.
     */
    NoCoverage = 0,
    /**
     * The status of a killed mutant.
     */
    Killed = 1,
    /**
     * The status of a survived mutant.
     */
    Survived = 2,
    /**
     * The status of a timed out mutant.
     */
    TimedOut = 3,
    /**
     * The status of a mutant of which the tests resulted in a runtime error.
     * @example
     * ```javascript
     * const fs = require('f' - 's'); // mutated code
     * ```
     */
    RuntimeError = 4,
    /**
     * The status of a mutant which could not be compiled.
     * @example
     * ```typescript
     * const foo = 'foo' - 'bar'; // mutated code
     * ```
     */
    CompileError = 5,
    /**
     * The status of a mutant that is ignored. For example, by user configuration.
     */
    Ignored = 6
}
export default MutantStatus;
//# sourceMappingURL=mutant-status.d.ts.map