"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toMutantRunResult = void 0;
const test_status_1 = require("./test-status");
const dry_run_status_1 = require("./dry-run-status");
const mutant_run_result_1 = require("./mutant-run-result");
function toMutantRunResult(dryRunResult) {
    switch (dryRunResult.status) {
        case dry_run_status_1.DryRunStatus.Complete: {
            const killedBy = dryRunResult.tests.find((test) => test.status === test_status_1.TestStatus.Failed);
            const nrOfTests = dryRunResult.tests.filter((test) => test.status !== test_status_1.TestStatus.Skipped).length;
            if (killedBy) {
                return {
                    status: mutant_run_result_1.MutantRunStatus.Killed,
                    failureMessage: killedBy.failureMessage,
                    killedBy: killedBy.id,
                    nrOfTests,
                };
            }
            else {
                return {
                    status: mutant_run_result_1.MutantRunStatus.Survived,
                    nrOfTests,
                };
            }
        }
        case dry_run_status_1.DryRunStatus.Error:
            return {
                status: mutant_run_result_1.MutantRunStatus.Error,
                errorMessage: dryRunResult.errorMessage,
            };
        case dry_run_status_1.DryRunStatus.Timeout:
            return {
                status: mutant_run_result_1.MutantRunStatus.Timeout,
            };
    }
}
exports.toMutantRunResult = toMutantRunResult;
//# sourceMappingURL=run-result-helpers.js.map